==> DateTime-Locale-1.35.tar.gz: DateTime-Locale-1.35/share/fy-NL.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d-M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'wike' W 'fan' MMMM",
    "MMMMW-count-other" => "'wike' W 'fan' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d-M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M-y",
    yMEd => "E d-M-y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d-M-y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'wike' w 'fan' Y",
    "yw-count-other" => "'wike' w 'fan' Y",
  },
  code => "fy-NL",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd-MM-yy",
  datetime_format_full => "{1} 'om' {0}",
  datetime_format_long => "{1} 'om' {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "mo",
    "ti",
    "wo",
    "to",
    "fr",
    "so",
    "si",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "moandei",
    "tiisdei",
    "woansdei",
    "tongersdei",
    "freed",
    "sneon",
    "snein",
  ],
  day_stand_alone_abbreviated => [
    "mo",
    "ti",
    "wo",
    "to",
    "fr",
    "so",
    "si",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "moandei",
    "tiisdei",
    "woansdei",
    "tongersdei",
    "freed",
    "sneon",
    "snein",
  ],
  era_abbreviated => [
    "f.Kr.",
    "n.Kr.",
  ],
  era_narrow => [
    "f.K.",
    "n.K.",
  ],
  era_wide => [
    "Foar Kristus",
    "nei Kristus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d-%m-%y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Western Frisian",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mrt",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Jannewaris",
    "Febrewaris",
    "Maart",
    "April",
    "Maaie",
    "Juny",
    "July",
    "Augustus",
    "Septimber",
    "Oktober",
    "Novimber",
    "Desimber",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mrt",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Jannewaris",
    "Febrewaris",
    "Maart",
    "April",
    "Maaie",
    "Juny",
    "July",
    "Augustus",
    "Septimber",
    "Oktober",
    "Novimber",
    "Desimber",
  ],
  name => "Western Frisian Netherlands",
  native_language => "Frysk",
  native_name => "Frysk Nederl\N{U+00e2}n",
  native_script => undef,
  native_territory => "Nederl\N{U+00e2}n",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1e fearnsjier",
    "2e fearnsjier",
    "3e fearnsjier",
    "4e fearnsjier",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1e fearnsjier",
    "2e fearnsjier",
    "3e fearnsjier",
    "4e fearnsjier",
  ],
  script => undef,
  territory => "Netherlands",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}

==> DateTime-Locale-1.37.tar.gz: DateTime-Locale-1.37/share/fy-NL.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d-M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'wike' W 'fan' MMMM",
    "MMMMW-count-other" => "'wike' W 'fan' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d-M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M-y",
    yMEd => "E d-M-y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d-M-y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'wike' w 'fan' Y",
    "yw-count-other" => "'wike' w 'fan' Y",
  },
  code => "fy-NL",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd-MM-yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "mo",
    "ti",
    "wo",
    "to",
    "fr",
    "so",
    "si",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "moandei",
    "tiisdei",
    "woansdei",
    "tongersdei",
    "freed",
    "sneon",
    "snein",
  ],
  day_stand_alone_abbreviated => [
    "mo",
    "ti",
    "wo",
    "to",
    "fr",
    "so",
    "si",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "moandei",
    "tiisdei",
    "woansdei",
    "tongersdei",
    "freed",
    "sneon",
    "snein",
  ],
  era_abbreviated => [
    "f.Kr.",
    "n.Kr.",
  ],
  era_narrow => [
    "f.K.",
    "n.K.",
  ],
  era_wide => [
    "Foar Kristus",
    "nei Kristus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %Z",
  glibc_date_format => "%d-%m-%y",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Western Frisian",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mrt",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Jannewaris",
    "Febrewaris",
    "Maart",
    "April",
    "Maaie",
    "Juny",
    "July",
    "Augustus",
    "Septimber",
    "Oktober",
    "Novimber",
    "Desimber",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mrt",
    "Apr",
    "Mai",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Okt",
    "Nov",
    "Des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Jannewaris",
    "Febrewaris",
    "Maart",
    "April",
    "Maaie",
    "Juny",
    "July",
    "Augustus",
    "Septimber",
    "Oktober",
    "Novimber",
    "Desimber",
  ],
  name => "Western Frisian Netherlands",
  native_language => "Frysk",
  native_name => "Frysk Nederl\N{U+00e2}n",
  native_script => undef,
  native_territory => "Nederl\N{U+00e2}n",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1e fearnsjier",
    "2e fearnsjier",
    "3e fearnsjier",
    "4e fearnsjier",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1e fearnsjier",
    "2e fearnsjier",
    "3e fearnsjier",
    "4e fearnsjier",
  ],
  script => undef,
  territory => "Netherlands",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 42,
}
